@@ -1,6 +1,13 @@
 # -*- coding: utf-8 -*-
 
-class AddonIncompatible(BaseException):
+"""
+Copyright (C) 2010 by Indifex (www.indifex.com), see AUTHORS.
+License: BSD, see LICENSE for details.
+
+For further information visit http://code.indifex.com/django-addons
+"""
+
+class AddonIncompatible(Exception):
     """
     This should be thrown when addon wants to import
     something from the base Django project but can't find it.
